.. _EB:

Running EclipsingBinaries
=========================

Script
------

To run the package in a command line (windows, anaconda, xterm, etc), simply run::

  EclipsingBinaries

This will bring up multiple options that the user can choose and will be described in the next section.
